"use strict";

import React, { useState, useEffect } from 'react';
import { Image } from 'react-native';

/**
 * An image asset that has to be loaded from a URI
 */

/**
 * An image asset that is loaded from a require('path/to/file') call
 */

/**
 * A source for the image loader
 */

/**
 * Fallback image asset(s)
 */
import { jsx as _jsx } from "react/jsx-runtime";
// Helper function to get all sources
const getAllSources = (source, fallback) => {
  const result = [source];
  if (fallback) {
    if (Array.isArray(fallback)) {
      result.push(...fallback);
    } else {
      result.push(fallback);
    }
  }
  return result;
};

/**
 * A barebones image loader component that can handle falling back to backup images when the primary image fails to load
 */
export const ImageLoader = props => {
  const {
    // After spending a few hours trying to get this to work, I'm giving up
    // As a workaround, I'm casting the `Image` component to `any`
    // TODO: Fix this typing
    component: CustomComponent = Image,
    source,
    fallback,
    onError,
    ...rest
  } = props;
  const allSources = getAllSources(source, fallback);
  const [currentSource, setCurrentSource] = useState(source);
  const [fallbackIndex, setFallbackIndex] = useState(0);

  // Start with the source prop
  // And reset the index when the source or fallback changes
  useEffect(() => {
    setCurrentSource(source);
    setFallbackIndex(0);
  }, [source, fallback]);
  const handleError = error => {
    // If we have more sources to try, move to the next one
    const nextIndex = fallbackIndex + 1;
    const nextSource = allSources[nextIndex];
    if (nextSource) {
      setFallbackIndex(nextIndex);
      setCurrentSource(nextSource);
    } else {
      // The sources have been exhausted
      // Call the onError callback if provided
      onError?.(error);
    }
  };
  return /*#__PURE__*/_jsx(CustomComponent, {
    source: currentSource,
    onError: handleError,
    ...rest
  });
};
//# sourceMappingURL=ImageLoader.js.map