import React from 'react';
import { type ImageProps, type ImageURISource, type ImageRequireSource } from 'react-native';
/**
 * An image asset that has to be loaded from a URI
 */
export type TImageLoaderSourceUri = ImageURISource;
/**
 * An image asset that is loaded from a require('path/to/file') call
 */
export type TImageLoaderSourceRequire = ImageRequireSource;
/**
 * A source for the image loader
 */
export type TImageLoaderSource = TImageLoaderSourceUri | TImageLoaderSourceRequire;
/**
 * Fallback image asset(s)
 */
export type TImageLoaderFallback = TImageLoaderSource | TImageLoaderSource[];
export type TImageLoaderProps<T = ImageProps> = T & {
    /**
     * Custom component to be used instead of react-native Image component
     * Defaults to `Image` component from `react-native`
     */
    component?: React.ComponentType<T>;
    /**
     * The image asset to load
     */
    source: TImageLoaderSource;
    /**
     * The fallback image asset(s)
     * This can be a single source or an array of sources
     * If an array is given, the image loader will try each source in order
     * until one of them loads successfully.
     * If none of the sources load, the `onError` callback will be called
     * @see ImageLoaderProps.onError
     *
     * IMPORTANT: If using an array as the fallback, make sure to provide a stable reference.
     * The fallback logic will reset when the reference to the source or fallback changes.
     */
    fallback?: TImageLoaderFallback;
};
/**
 * A barebones image loader component that can handle falling back to backup images when the primary image fails to load
 */
export declare const ImageLoader: React.FC<TImageLoaderProps>;
//# sourceMappingURL=ImageLoader.d.ts.map